FUNCTION PLACES2K_READ, FILE

; Read the US Census Bureau 2000 List of Place Names and Locations
;
; http://www.census.gov/geo/www/gazetteer/places2k.html
;
; The place file contains data for all Incorporated and Census Designated
; places in the 50 states, the District of Columbia and Puerto Rico as of
; January 1, 2000. The file is plain ASCII text, one line per record. 
;
; Columns 1-2: United States Postal Service State Abbreviation 
; Columns 3-4: State Federal Information Processing Standard (FIPS) code 
; Columns 5-9: Place FIPS Code 
; Columns 10-73: Name Includes name of place and type
;   ('city', 'town', 'borough', 'village', 'CDP', 'zona urbana', 'comunidad').
; Columns 74-82: Total Population (2000) 
; Columns 83-91: Total Housing Units (2000) 
; Columns 92-105: Land Area (square meters) 
; Columns 106-119: Water Area(square meters) 
; Columns 120-131: Land Area (square miles) 
; Columns 132-143: Water Area (square miles) 
; Columns 144-153: Latitude (decimal degrees)
;   First character is blank or "-" denoting North or South latitude respectively 
; Columns 154-164: Longitude (decimal degrees)
;   First character is blank or "-" denoting East or West longitude respectively
;
; Liam.Gumley@ssec.wisc.edu 24-JUN-2002

;- Open the file
openr, lun, file, /get_lun

;- Define the input format
fmt = '(a2, t10, a64, t73, a1, t74, i9, t144, f10.6, f11.6)'

;- Define input record
rec = {$
  state_name:'', $
  place_name:'', $
  place_type:'', $
  population:0L, $
  latitude:0.0D, $
  longitude:0.0D $
  }

;- Define output array
data = replicate(rec, 50000)

;- Read the file
record = rec
recnum = 0L
while (eof(lun) ne 1) do begin
  readf, lun, record, format=fmt
  data[recnum] = record
  recnum = recnum + 1L
endwhile

;- Trim the output array
data = data[ 0L : (recnum - 1L)]

;- Trim trailing blanks from place names
data.place_name = strtrim(data.place_name, 2)

;- Set the list of place types
type_list = ['city', 'town', 'borough', 'village', $
  'CDP', 'zona urbana', 'comunidad']

;- Trim place type from place names
for i = 0L, n_elements(type_list) - 1L do begin

  ;- Get place names which match this place type
  result = strpos(data.place_name, type_list[i])
  loc = where(result gt 0, count)
  
  ;- Remove types from place names, and save types separately
  for j = 0L, count - 1L do begin
    place_name = data[loc[j]].place_name
    data[loc[j]].place_name = strmid(place_name, 0, result[loc[j]] - 1)
    data[loc[j]].place_type = strmid(place_name, result[loc[j]])
  endfor
  
endfor

;- Close the file
free_lun, lun

;- Return the result
return, data

END
